@@ -14,8 +14,8 @@ def register():
         Category,
         Party,
         PartyCategory,
+        PartyIdentifier,
         CheckVIESResult,
-        CheckVIESNoResult,
         Address,
         ContactMechanism,
         Configuration,
